==> VariantFiltering_1.14.0.tar.gz: VariantFiltering/R/AllGeneric.R <==
## for FiveSpliceSiteVariants and ThreeSpliceSiteVariants
setGeneric("minIntronLength", function(x) standardGeneric("minIntronLength"))
setGeneric("minIntronLength<-", function(x, value) standardGeneric("minIntronLength<-"))

## for GenePhylostrataDb class
setGeneric("genePhylostratum", function(object, ids) standardGeneric("genePhylostratum"))
setGeneric("genePhylostrata", function(object) standardGeneric("genePhylostrata"))

## for VariantFilteringParam and VariantFilteringResults class
setGeneric("filters", function(x) standardGeneric("filters"))
setGeneric("filters<-", function(x, value) standardGeneric("filters<-"))
setGeneric("cutoffs", function(x) standardGeneric("cutoffs"))
setGeneric("cutoffs<-", function(x, value) standardGeneric("cutoffs<-"))
setGeneric("sog", function(x) standardGeneric("sog"))
setGeneric("sodmat", function(x) standardGeneric("sodmat"))
setGeneric("soamat", function(x) standardGeneric("soamat"))

## for VariantFilteringResults class
setGeneric("samples<-", function(object, value) standardGeneric("samples<-"))
setGeneric("resetSamples", function(object, value) standardGeneric("resetSamples"))
setGeneric("bamFiles", function(object) standardGeneric("bamFiles"))
setGeneric("bamFiles<-", function(object, value) standardGeneric("bamFiles<-"))
setGeneric("VariantFilteringResults", function(variants, ...) standardGeneric("VariantFilteringResults"))
setGeneric("inheritanceModel", function(x) standardGeneric("inheritanceModel"))
setGeneric("param", function(x) standardGeneric("param"))
setGeneric("allVariants", function(x, ...) standardGeneric("allVariants"))
setGeneric("filteredVariants", function(x, ...) standardGeneric("filteredVariants"))
setGeneric("annoGroups", function(x, ...) standardGeneric("annoGroups"))
setGeneric("dbSNPpresent", function(x) standardGeneric("dbSNPpresent"))
setGeneric("dbSNPpresent<-", function(x, value) standardGeneric("dbSNPpresent<-"))
setGeneric("OMIMpresent", function(x) standardGeneric("OMIMpresent"))
setGeneric("OMIMpresent<-", function(x, value) standardGeneric("OMIMpresent<-"))
setGeneric("variantType", function(x) standardGeneric("variantType"))
setGeneric("variantType<-", function(x, typkey=NA, value) standardGeneric("variantType<-"))
setGeneric("variantLocation", function(x) standardGeneric("variantLocation"))
setGeneric("variantLocation<-", function(x, lockey=NA, value) standardGeneric("variantLocation<-"))
setGeneric("variantConsequence", function(x) standardGeneric("variantConsequence"))
setGeneric("variantConsequence<-", function(x, conkey=NA, value) standardGeneric("variantConsequence<-"))
setGeneric("aaChangeType", function(x) standardGeneric("aaChangeType"))
setGeneric("aaChangeType<-", function(x, value) standardGeneric("aaChangeType<-"))
setGeneric("naMAF", function(x) standardGeneric("naMAF"))
setGeneric("naMAF<-", function(x, value) standardGeneric("naMAF<-"))
setGeneric("MAFpop", function(x) standardGeneric("MAFpop"))
setGeneric("MAFpop<-", function(x, popkey=NA, value) standardGeneric("MAFpop<-"))
setGeneric("maxMAF", function(x) standardGeneric("maxMAF"))
setGeneric("maxMAF<-", function(x, value) standardGeneric("maxMAF<-"))
setGeneric("minPhastCons", function(x) standardGeneric("minPhastCons"))
setGeneric("minPhastCons<-", function(x, value) standardGeneric("minPhastCons<-"))
setGeneric("minPhylostratum", function(x) standardGeneric("minPhylostratum"))
setGeneric("minPhylostratum<-", function(x, value) standardGeneric("minPhylostratum<-"))
setGeneric("minScore5ss", function(x) standardGeneric("minScore5ss"))
setGeneric("minScore5ss<-", function(x, value) standardGeneric("minScore5ss<-"))
setGeneric("minScore3ss", function(x) standardGeneric("minScore3ss"))
setGeneric("minScore3ss<-", function(x, value) standardGeneric("minScore3ss<-"))
setGeneric("minCUFC", function(x) standardGeneric("minCUFC"))
setGeneric("minCUFC<-", function(x, value) standardGeneric("minCUFC<-"))
setGeneric("reportVariants", function(vfResultsObj, ...) standardGeneric("reportVariants"))

## for the rest ..
setGeneric("xLinked", function(param, ...) standardGeneric("xLinked"))
setGeneric("autosomalRecessiveHomozygous", function(param, ...) standardGeneric("autosomalRecessiveHomozygous"))
setGeneric("autosomalDominant", function(param, ...) standardGeneric("autosomalDominant"))
setGeneric("deNovo", function(param, ...) standardGeneric("deNovo"))
setGeneric("autosomalRecessiveHeterozygous", function(param, ...) standardGeneric("autosomalRecessiveHeterozygous"))
setGeneric("unrelatedIndividuals", function(param, ...) standardGeneric("unrelatedIndividuals"))
setGeneric("annotateVariants", function(annObj, ...) standardGeneric("annotateVariants"))
setGeneric("wmScore", function(object, dnaseqs, ...) standardGeneric("wmScore"))
setGeneric("conservedPositions", function(x, ...) standardGeneric("conservedPositions"))
setGeneric("wmName", function(x, ...) standardGeneric("wmName"))
setGeneric("wmFilename", function(x, ...) standardGeneric("wmFilename"))
setGeneric("wmLocations", function(x, ...) standardGeneric("wmLocations"))
setGeneric("wmLocations<-", function(x, value) standardGeneric("wmLocations<-"))
setGeneric("wmStrictLocations", function(x, ...) standardGeneric("wmStrictLocations"))
setGeneric("wmStrictLocations<-", function(x, value) standardGeneric("wmStrictLocations<-"))

==> VariantFiltering_1.18.0.tar.gz: VariantFiltering/R/AllGeneric.R <==
## for FiveSpliceSiteVariants and ThreeSpliceSiteVariants
setGeneric("minIntronLength", function(x) standardGeneric("minIntronLength"))
setGeneric("minIntronLength<-", function(x, value) standardGeneric("minIntronLength<-"))

## for GenePhylostrataDb class
setGeneric("genePhylostratum", function(object, ids) standardGeneric("genePhylostratum"))
setGeneric("genePhylostrata", function(object) standardGeneric("genePhylostrata"))

## for VariantFilteringParam and VariantFilteringResults class
setGeneric("filters", function(x) standardGeneric("filters"))
setGeneric("filters<-", function(x, value) standardGeneric("filters<-"))
setGeneric("filtersMetadata", function(x) standardGeneric("filtersMetadata"))
setGeneric("cutoffs", function(x) standardGeneric("cutoffs"))
setGeneric("cutoffs<-", function(x, value) standardGeneric("cutoffs<-"))
setGeneric("change<-", function(x, cutoff, value) standardGeneric("change<-"))
setGeneric("sortings", function(x) standardGeneric("sortings"))
setGeneric("sortings<-", function(x, value) standardGeneric("sortings<-"))
setGeneric("sog", function(x, ...) standardGeneric("sog"))
setGeneric("sodmat", function(x) standardGeneric("sodmat"))
setGeneric("soamat", function(x) standardGeneric("soamat"))

## for VariantFilteringResults class only
setGeneric("samples<-", function(object, value) standardGeneric("samples<-"))
setGeneric("resetSamples", function(object, value) standardGeneric("resetSamples"))
setGeneric("bamFiles", function(object) standardGeneric("bamFiles"))
setGeneric("bamFiles<-", function(object, value) standardGeneric("bamFiles<-"))
setGeneric("VariantFilteringResults", function(variants, ...) standardGeneric("VariantFilteringResults"))
setGeneric("inheritanceModel", function(x) standardGeneric("inheritanceModel"))
setGeneric("param", function(x) standardGeneric("param"))
setGeneric("allVariants", function(x, ...) standardGeneric("allVariants"))
setGeneric("filteredVariants", function(x, ...) standardGeneric("filteredVariants"))
setGeneric("annoGroups", function(x, ...) standardGeneric("annoGroups"))
setGeneric("minScore5ss", function(x) standardGeneric("minScore5ss"))
setGeneric("minScore5ss<-", function(x, value) standardGeneric("minScore5ss<-"))
setGeneric("minScore3ss", function(x) standardGeneric("minScore3ss"))
setGeneric("minScore3ss<-", function(x, value) standardGeneric("minScore3ss<-"))
setGeneric("minCUFC", function(x) standardGeneric("minCUFC"))
setGeneric("minCUFC<-", function(x, value) standardGeneric("minCUFC<-"))
setGeneric("reportVariants", function(vfResultsObj, ...) standardGeneric("reportVariants"))

## .. being deprecated ..
setGeneric("dbSNPpresent", function(x) standardGeneric("dbSNPpresent"))
setGeneric("dbSNPpresent<-", function(x, value) standardGeneric("dbSNPpresent<-"))
setGeneric("OMIMpresent", function(x) standardGeneric("OMIMpresent"))
setGeneric("OMIMpresent<-", function(x, value) standardGeneric("OMIMpresent<-"))
setGeneric("variantType", function(x) standardGeneric("variantType"))
setGeneric("variantType<-", function(x, typkey=NA, value) standardGeneric("variantType<-"))
setGeneric("variantLocation", function(x) standardGeneric("variantLocation"))
setGeneric("variantLocation<-", function(x, lockey=NA, value) standardGeneric("variantLocation<-"))
setGeneric("variantConsequence", function(x) standardGeneric("variantConsequence"))
setGeneric("variantConsequence<-", function(x, conkey=NA, value) standardGeneric("variantConsequence<-"))
setGeneric("aaChangeType", function(x) standardGeneric("aaChangeType"))
setGeneric("aaChangeType<-", function(x, value) standardGeneric("aaChangeType<-"))
setGeneric("naMAF", function(x) standardGeneric("naMAF"))
setGeneric("naMAF<-", function(x, value) standardGeneric("naMAF<-"))
setGeneric("MAFpop", function(x) standardGeneric("MAFpop"))
setGeneric("MAFpop<-", function(x, popkey=NA, value) standardGeneric("MAFpop<-"))
setGeneric("maxMAF", function(x) standardGeneric("maxMAF"))
setGeneric("maxMAF<-", function(x, value) standardGeneric("maxMAF<-"))
setGeneric("minPhastCons", function(x) standardGeneric("minPhastCons"))
setGeneric("minPhastCons<-", function(x, value) standardGeneric("minPhastCons<-"))
setGeneric("minPhylostratum", function(x) standardGeneric("minPhylostratum"))
setGeneric("minPhylostratum<-", function(x, value) standardGeneric("minPhylostratum<-"))

## for the rest ..
setGeneric("xLinked", function(param, ...) standardGeneric("xLinked"))
setGeneric("autosomalRecessiveHomozygous", function(param, ...) standardGeneric("autosomalRecessiveHomozygous"))
setGeneric("autosomalDominant", function(param, ...) standardGeneric("autosomalDominant"))
setGeneric("deNovo", function(param, ...) standardGeneric("deNovo"))
setGeneric("autosomalRecessiveHeterozygous", function(param, ...) standardGeneric("autosomalRecessiveHeterozygous"))
setGeneric("unrelatedIndividuals", function(param, ...) standardGeneric("unrelatedIndividuals"))
setGeneric("annotateVariants", function(annObj, ...) standardGeneric("annotateVariants"))
setGeneric("wmScore", function(object, dnaseqs, ...) standardGeneric("wmScore"))
setGeneric("conservedPositions", function(x, ...) standardGeneric("conservedPositions"))
setGeneric("wmName", function(x, ...) standardGeneric("wmName"))
setGeneric("wmFilename", function(x, ...) standardGeneric("wmFilename"))
setGeneric("wmLocations", function(x, ...) standardGeneric("wmLocations"))
setGeneric("wmLocations<-", function(x, value) standardGeneric("wmLocations<-"))
setGeneric("wmStrictLocations", function(x, ...) standardGeneric("wmStrictLocations"))
setGeneric("wmStrictLocations<-", function(x, value) standardGeneric("wmStrictLocations<-"))
